@@ -69,7 +69,7 @@ struct _NautilusBurnProcess {
 	GString                  *line_stderr;
 	NautilusBurnProcessFuncs *funcs;
 
-	int                       stdin;
+	int                       pipe_stdin;
 
 	time_t                    start_time;
 	gint64                    start_num;
@@ -309,7 +309,7 @@ insert_cd_retry (NautilusBurnProcess *process,
 		nautilus_burn_process_cancel (process, FALSE);
 	} else if (is_reload) {
 		if (send_return) {
-			write (process->stdin, "\n", 1);
+			write (process->pipe_stdin, "\n", 1);
 		} else {
 			kill (process->pid, SIGUSR1);
 		}
@@ -1248,7 +1248,7 @@ nautilus_burn_recorder_run_process (NautilusBurnRecorder       *recorder,
 				      recorder,
 				      &stdout_tag,
 				      &stderr_tag,
-				      &process->stdin,
+				      &process->pipe_stdin,
 				      &local_error);
 
 	if (! res) {
