@@ -834,6 +834,7 @@ setup_close_button (NautilusBurnerWriteData *data)
 
 	gtk_widget_hide (cancel_button);
 	gtk_widget_show (close_button);
+	gtk_widget_grab_focus (close_button);
 
 	g_signal_connect (close_button, "clicked", G_CALLBACK (gtk_main_quit), NULL);
 
@@ -1199,7 +1200,13 @@ burn_cd (const NautilusBurnDrive *drive,
 			if (path != NULL && path[0] != '\0') {
 				filename = g_build_filename (path, "image.iso.XXXXXX", NULL);
 				fd = g_mkstemp (filename);
-				close (fd);
+				if (fd < 0) {
+					g_error ("Could not create temporary filename for ISO image");
+					res = NAUTILUS_BURN_RECORDER_RESULT_ERROR;
+					goto out;
+				} else {
+					close (fd);
+				}
 			}
 
 			g_free (path);
@@ -1264,7 +1271,13 @@ burn_cd (const NautilusBurnDrive *drive,
 
 			filename = g_build_filename (g_get_tmp_dir (), "image.iso.XXXXXX", NULL);
 			fd = g_mkstemp (filename);
-			close (fd);
+			if (fd < 0) {
+				g_error ("Could not create temporary filename for ISO image");
+				res = NAUTILUS_BURN_RECORDER_RESULT_ERROR;
+				goto out;
+			} else {
+				close (fd);
+			}
 
 			image_flags &= ~NAUTILUS_BURN_IMAGE_CREATE_WARN_SPACE;
 
@@ -1285,7 +1298,13 @@ burn_cd (const NautilusBurnDrive *drive,
 
 				filename = g_build_filename (g_get_home_dir (), ".image.iso.XXXXXX", NULL);
 				fd = g_mkstemp (filename);
-				close (fd);
+				if (fd < 0) {
+					g_error ("Could not create temporary filename for ISO image");
+					res = NAUTILUS_BURN_RECORDER_RESULT_ERROR;
+					goto out;
+				} else {
+					close (fd);
+				}
 
 				image_flags |= NAUTILUS_BURN_IMAGE_CREATE_WARN_SPACE;
 
@@ -1620,6 +1639,7 @@ init_dialog (GladeXML        *xml,
 	refresh_dialog (xml);
 }
 
+/* Returns TRUE if writing should be cancelled */
 static gboolean
 ask_cancel (void)
 {
@@ -1650,6 +1670,8 @@ ask_cancel (void)
 static void
 do_cancel (void)
 {
+	gboolean cancelled;
+
 	if (cancel == CANCEL_NONE) {
 		return;
 	}
@@ -1659,13 +1681,14 @@ do_cancel (void)
 		return;
 	}
 
-	if (nautilus_burn_recorder_cancel (recorder, TRUE) != FALSE) {
-		if (ask_cancel () == FALSE) {
-			return;
+	cancelled = nautilus_burn_recorder_cancel (recorder, TRUE);
+
+	if (! cancelled) {
+		if (ask_cancel () == TRUE) {
+			/* do the dangerous cancel */
+			nautilus_burn_recorder_cancel (recorder, FALSE);
 		}
 	}
-
-	nautilus_burn_recorder_cancel (recorder, FALSE);
 }
 
 static gboolean
